@@ -1,19 +1,24 @@
+import stringcase
+from troposphere.sqs import Queue
+
 from serverless.aws.types import SQSArn
 from serverless.service.types import Identifier, YamlOrderedDict
-from troposphere.sqs import Queue
 
 
 class Function(YamlOrderedDict):
     yaml_tag = "!Function"
 
-    def __init__(self, service, name, description, handler=None, timeout=None, layers=None):
+    def __init__(self, service, name, description, handler=None, timeout=None, layers=None, **kwargs):
         super().__init__()
         self._service = service
-        self.name = Identifier(name)
+        self.key = stringcase.pascalcase(stringcase.snakecase(name).lower())
+        self.name = Identifier(
+            self._service.service.spinal.lower() + "-${sls:stage}" + "-" + stringcase.spinalcase(name).lower()
+        )
         self.description = description
 
         if not handler:
-            handler = f"{self._service.service.snake}/{self.name.snake}:handler"
+            handler = f"{self._service.service.snake}.{stringcase.snakecase(name)}.handler"
 
         self.handler = handler
         self.events = []
@@ -24,11 +29,19 @@ class Function(YamlOrderedDict):
         if timeout:
             self.timeout = timeout
 
+        for name, value in kwargs.items():
+            setattr(self, name, value)
+
     def trigger(self, event):
         self.events.append(event)
 
         return event
 
+    def apply(self, **kwargs):
+        for event in self.events:
+            for k, v in kwargs.items():
+                event[k] = v
+
     def use_async_dlq(self, onFailuredlqArn=None, maximumEventAge=3600, maximumRetryAttempts=3):
         if not onFailuredlqArn:
             name = f"{self.name.spinal}-dlq"
@@ -42,7 +55,11 @@ class Function(YamlOrderedDict):
     def to_yaml(cls, dumper, data):
         events = data.events
         data.pop("_service", None)
+        data.pop("key", None)
 
-        data.events = [{event.yaml_tag: event} for event in events]
+        if not data.events:
+            del data["events"]
+        else:
+            data.events = [{event.yaml_tag: event} for event in events]
 
         return dumper.represent_dict(data)
