@@ -31,31 +31,92 @@ class FunctionBuilder:
         super().__init__()
         self.service = service
 
-    def generic(self, name, description, handler=None, timeout=None, layers=None) -> Function:
-        fn = Function(self.service, name, description, handler, timeout, layers)
+    def generic(self, name, description, handler=None, timeout=None, layers=None, **kwargs) -> Function:
+        fn = Function(self.service, name, description, handler, timeout, layers, **kwargs)
         self.service.functions.add(fn)
 
         return fn
 
     def http(
-            self, name, description, path, method, authorizer=None, handler=None, timeout=None, layers=None
+        self, name, description, path, method, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
     ) -> HTTPFunction:
-        fn = HTTPFunction(self.service, name, description, path, method, authorizer, handler, timeout, layers)
+        fn = HTTPFunction(self.service, name, description, path, method, authorizer, handler, timeout, layers, **kwargs)
+        self.service.functions.add(fn)
+
+        return fn
+
+    def http_post(
+        self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
+    ) -> HTTPFunction:
+        fn = HTTPFunction(
+            self.service, name, description, path, HTTPFunction.POST, authorizer, handler, timeout, layers, **kwargs
+        )
+        self.service.functions.add(fn)
+
+        return fn
+
+    def http_get(
+        self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
+    ) -> HTTPFunction:
+        fn = HTTPFunction(
+            self.service, name, description, path, HTTPFunction.GET, authorizer, handler, timeout, layers, **kwargs
+        )
+        self.service.functions.add(fn)
+
+        return fn
+
+    def http_put(
+        self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
+    ) -> HTTPFunction:
+        fn = HTTPFunction(
+            self.service, name, description, path, HTTPFunction.PUT, authorizer, handler, timeout, layers, **kwargs
+        )
+        self.service.functions.add(fn)
+
+        return fn
+
+    def http_delete(
+        self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
+    ) -> HTTPFunction:
+        fn = HTTPFunction(
+            self.service, name, description, path, HTTPFunction.DELETE, authorizer, handler, timeout, layers, **kwargs
+        )
+        self.service.functions.add(fn)
+
+        return fn
+
+    def http_options(
+        self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
+    ) -> HTTPFunction:
+        fn = HTTPFunction(
+            self.service, name, description, path, HTTPFunction.OPTIONS, authorizer, handler, timeout, layers, **kwargs
+        )
+        self.service.functions.add(fn)
+
+        return fn
+
+    def http_any(
+        self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
+    ) -> HTTPFunction:
+        fn = HTTPFunction(
+            self.service, name, description, path, HTTPFunction.ANY, authorizer, handler, timeout, layers, **kwargs
+        )
         self.service.functions.add(fn)
 
         return fn
 
     def event_bridge(
-            self,
-            name,
-            description,
-            eventBus,
-            pattern=None,
-            deadLetterQueueArn=None,
-            retryPolicy=None,
-            handler=None,
-            timeout=None,
-            layers=None,
+        self,
+        name,
+        description,
+        eventBus,
+        pattern=None,
+        deadLetterQueueArn=None,
+        retryPolicy=None,
+        handler=None,
+        timeout=None,
+        layers=None,
+        **kwargs,
     ) -> EventBridgeFunction:
         fn = EventBridgeFunction(
             self.service,
@@ -68,6 +129,7 @@ class FunctionBuilder:
             handler,
             timeout,
             layers,
+            **kwargs,
         )
         self.service.functions.add(fn)
 
@@ -78,11 +140,9 @@ class Provider(BaseProvider, yaml.YAMLObject):
     yaml_tag = "!Provider"
 
     def __init__(
-            self, runtime=Runtime.PYTHON_3_8, extra_tags=None, timeout=60, stage="development", environment=None, /,
-            **kwds
+        self, runtime=Runtime.PYTHON_3_8, extra_tags=None, timeout=10, stage="development", environment=None, **kwargs
     ):
-        super().__init__(**kwds)
-
+        super().__init__(**kwargs)
         self.deploymentBucket = None
         self._service = None
         self.function_builder = None
@@ -96,20 +156,15 @@ class Provider(BaseProvider, yaml.YAMLObject):
         self.lambdaHashingVersion = 20201221
         self.environment = environment or Environment()
         self.iam = None
-        self.apiGateway = dict(
-            shouldStartNameWithService=True
-        )
-        self.eventBridge = dict(
-            useCloudFormation=True
-        )
+        self.apiGateway = dict(shouldStartNameWithService=True)
+        self.eventBridge = dict(useCloudFormation=True)
 
     def configure(self, service):
         self._service = service
         self.deploymentBucket = dict(
-            name=f"sls-deployments.${{self:custom.region}}."
-                 f"${{self:custom.stage}}{self._service.config.domain(prefix='.')}"
+            name=f'sls-deployments.${{aws:region}}.${{sls:stage}}.${{self:custom.vars.domain, "app"}}'
         )
-        self.tags["SERVICE"] = self._service.service.spinal
+        self.tags["SERVICE"] = "${self:service}"
         self.iam = IAMManager(self._service)
         self.function_builder = FunctionBuilder(self._service)
 
